Author: Ralf Treinen <treinen@debian.org>
Description: Pervasives has become Stdlib in ocaml 4.07

Index: pplacer/common_src/mapsSets.ml
===================================================================
--- pplacer.orig/common_src/mapsSets.ml	2020-06-13 17:04:45.732114513 +0200
+++ pplacer/common_src/mapsSets.ml	2020-06-13 17:04:45.728116096 +0200
@@ -3,7 +3,7 @@
 
 module OrderedFloat = struct
   type t = float
-  let compare = Pervasives.compare
+  let compare = Stdlib.compare
 end
 
 module OrderedInt = struct
Index: pplacer/common_src/number.ml
===================================================================
--- pplacer.orig/common_src/number.ml	2020-06-13 17:04:45.732114513 +0200
+++ pplacer/common_src/number.ml	2020-06-13 17:04:45.728116096 +0200
@@ -44,7 +44,7 @@
   let max = ( || )
   let pow x y = if y then x else true
   let indic = ( = )
-  let compare = Pervasives.compare
+  let compare = Stdlib.compare
   let succ = not
   let abs x = x
   let inv _ = false
@@ -80,7 +80,7 @@
       aux y
   let indic x y =
     if x = y then 1 else 0
-  let compare = Pervasives.compare
+  let compare = Stdlib.compare
   let succ = (+) 1
   let abs = abs
   let conv_float_fun f =
@@ -118,7 +118,7 @@
   let max = bcheck max
   let pow = bcheck ( ** )
   let indic = bcheck (fun x y -> if x = y then 1. else 0.)
-  let compare = Pervasives.compare
+  let compare = Stdlib.compare
   let succ = (+.) 1.
   let abs = abs_float
   let inv = ucheck (fun x -> 1. /. x)
Index: pplacer/pplacer_src/guppy_squash.ml
===================================================================
--- pplacer.orig/pplacer_src/guppy_squash.ml	2020-06-13 17:04:45.732114513 +0200
+++ pplacer/pplacer_src/guppy_squash.ml	2020-06-13 17:04:45.728116096 +0200
@@ -17,7 +17,7 @@
 module NPreBlob =
   struct
     type t = int list * Mass_map.Pre.t
-    let compare = Pervasives.compare
+    let compare = Stdlib.compare
     let merge (l1, p1) (l2, p2) = (l1 @ l2, p1 @ p2)
   end
 
Index: pplacer/pplacer_src/newick_bark.ml
===================================================================
--- pplacer.orig/pplacer_src/newick_bark.ml	2020-06-13 17:04:45.732114513 +0200
+++ pplacer/pplacer_src/newick_bark.ml	2020-06-13 17:04:45.728116096 +0200
@@ -119,7 +119,7 @@
 let floato_approx_compare epsilon a b =
   match (a, b) with
   | (Some x, Some y) -> float_approx_compare epsilon x y
-  | (a, b) -> Pervasives.compare a b
+  | (a, b) -> Stdlib.compare a b
 
 let compare ?epsilon:(epsilon=0.) ?cmp_edge_label:(cmp_edge_label=true) b1 b2 =
   let fc = floato_approx_compare epsilon in
Index: pplacer/pplacer_src/squashfunc.ml
===================================================================
--- pplacer.orig/pplacer_src/squashfunc.ml	2020-06-13 17:04:45.732114513 +0200
+++ pplacer/pplacer_src/squashfunc.ml	2020-06-13 17:04:45.728116096 +0200
@@ -54,7 +54,7 @@
     let compare_cble a b =
       let cdist = compare a.dist b.dist in
       if cdist <> 0 then cdist
-      else Pervasives.compare a b
+      else Stdlib.compare a b
 
     let replace_blob distf oldb newb c =
       if c.small = oldb then cble_of_blobs distf c.big newb
Index: pplacer/pplacer_src/guppy_round.ml
===================================================================
--- pplacer.orig/pplacer_src/guppy_round.ml	2020-06-13 17:04:23.481803484 +0200
+++ pplacer/pplacer_src/guppy_round.ml	2020-06-13 17:05:31.011799071 +0200
@@ -48,7 +48,7 @@
   Map.Make
     (struct
       type t = rounded_pquery
-      let compare = Pervasives.compare
+      let compare = Stdlib.compare
     end)
 
 let add_listly k v m =

Index: pplacer/pplacer_src/tax_id.ml
===================================================================
--- pplacer.orig/pplacer_src/tax_id.ml	2020-06-13 17:04:45.732114513 +0200
+++ pplacer/pplacer_src/tax_id.ml	2020-06-13 17:04:45.728116096 +0200
@@ -1,6 +1,6 @@
 (* The taxonomic id type
  *
  * note use of Pervasives.compare should be redone if speed needed.
 *)
 
 open Ppatteries
@@ -67,7 +67,7 @@
 (* *** Maps and Sets *** *)
 module OrderedTaxId = struct
   type t = tax_id
-  let compare = Pervasives.compare
+  let compare = Stdlib.compare
 end
 
 module PprTaxId = struct
@@ -1,6 +1,6 @@
 (* The taxonomic id type
  *
- * note use of Pervasives.compare should be redone if speed needed.
+ * note use of Stdlib.compare should be redone if speed needed.
 *)
 